@@ -119,6 +119,9 @@ def train_model(config: dict, fun_control: dict, timestamp: bool = True) -> floa
         max_epochs=model.hparams.epochs,
         accelerator=fun_control["accelerator"],
         devices=fun_control["devices"],
+        strategy=fun_control["strategy"],
+        num_nodes=fun_control["num_nodes"],
+        precision=fun_control["precision"],
         logger=TensorBoardLogger(
             save_dir=fun_control["TENSORBOARD_PATH"],
             version=config_id,
